.. py:currentmodule:: rubin_scheduler.scheduler

.. _fbs-api:

=================
FBS Scheduler API
=================

.. toctree::

    Sim Runner <fbs-api-sim-runner>

    Example Scheduler <fbs-api-example-scheduler>

    Model Observatory <fbs-api-model-observatory>

    Schedulers <fbs-api-schedulers>

    Surveys <fbs-api-surveys>

    Basis Functions <fbs-api-basis-functions>

    Features <fbs-api-features>

    Detailers <fbs-api-detailers>

    Utils <fbs-api-utils>



